==> kendo-dropdowns-vue-wrapper-2022.1.412-dev.412.tgz: package/docs/multicolumncombobox/index.md <==
---
title: Overview
page_title: MultiColumnComboBox Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI MultiColumnComboBox wrapper for Vue delivers and use the component in Vue projects."
slug: overview_multicolumncombobox
position: 1
---

# MultiColumnComboBox Overview

The MultiColumnComboBox provides a list with a table-like drop-down structure for picking single items or entering custom values.

The MultiColumnComboBox wrapper for Vue is a client-side wrapper for the [Kendo UI MultiColumnComboBox](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox) widget.

<div data-component="StartFreeTrialSection"></div>

## Basic Usage

The following example demonstrates the MultiColumnComboBox in action.

{% meta height:350 %}
{% embed_file multicolumncombobox/basic/main.vue preview %}
{% embed_file multicolumncombobox/basic/main.js %}
{% endmeta %}

## Functionality and Features

* [Data binding]({% slug databinding_multicolumncombobox %})
* [Column features]({% slug columns_multicolumncombobox %})
* [Filtering]({% slug filtering_multicolumncombobox %})
* [Virtualization]({% slug virtualization_multicolumncombobox %})
* [Grouping]({% slug grouping_multicolumncombobox %})
* [Cascading MultiColumnComboBoxes]({% slug cascading_multicolumncombobox %})
* [Templates]({% slug templates_multicolumncombobox %})
* [Keyboard navigation]({% slug keyboard_navigation_multicolumncombobox %})
* [RTL support]({% slug rtl_support_multicolumncombobox %})

## Events

The following example demonstrates basic MultiColumnComboBox events. You can subscribe to [all MultiColumnComboBox events](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox#events) by the handler name.

{% meta height:350 %}
{% embed_file multicolumncombobox/events/main.vue preview %}
{% embed_file multicolumncombobox/events/main.js %}
{% endmeta %}

## Suggested Links

* [Kendo UI MultiColumnComboBox for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multicolumncombobox/overview)
* [API Reference of the MultiColumnComboBox Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox)

==> kendo-dropdowns-vue-wrapper-2023.1.117-dev.307.tgz: package/docs/multicolumncombobox/index.md <==
---
title: Overview
page_title: MultiColumnComboBox Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI MultiColumnComboBox wrapper for Vue delivers and use the component in Vue projects."
slug: overview_multicolumncombobox_wrapper
position: 1
---

# MultiColumnComboBox Overview

The MultiColumnComboBox provides a list with a table-like drop-down structure for picking single items or entering custom values.

The MultiColumnComboBox wrapper for Vue is a client-side wrapper for the [Kendo UI MultiColumnComboBox](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox) widget.

<div data-component="StartFreeTrialSection"></div>

## Basic Usage

The following example demonstrates the MultiColumnComboBox in action.

{% meta height:350 %}
{% embed_file multicolumncombobox/basic/main.vue preview %}
{% embed_file multicolumncombobox/basic/main.js %}
{% endmeta %}

## Functionality and Features

* [Data binding]({% slug databinding_multicolumncombobox_wrapper %})
* [Column features]({% slug columns_multicolumncombobox_wrapper %})
* [Filtering]({% slug filtering_multicolumncombobox_wrapper %})
* [Virtualization]({% slug virtualization_multicolumncombobox_wrapper %})
* [Grouping]({% slug grouping_multicolumncombobox_wrapper %})
* [Cascading MultiColumnComboBoxes]({% slug cascading_multicolumncombobox_wrapper %})
* [Templates]({% slug templates_multicolumncombobox_wrapper %})
* [Keyboard navigation]({% slug keyboard_navigation_multicolumncombobox_wrapper %})
* [RTL support]({% slug rtl_support_multicolumncombobox_wrapper %})

## Events

The following example demonstrates basic MultiColumnComboBox events. You can subscribe to [all MultiColumnComboBox events](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox#events) by the handler name.

{% meta height:350 %}
{% embed_file multicolumncombobox/events/main.vue preview %}
{% embed_file multicolumncombobox/events/main.js %}
{% endmeta %}

## Suggested Links

* [Kendo UI MultiColumnComboBox for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multicolumncombobox/overview)
* [API Reference of the MultiColumnComboBox Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox)
